summaryrefslogtreecommitdiffstats
path: root/src/core/hle/kernel/vm_manager.h
diff options
context:
space:
mode:
authorZach Hilman <DarkLordZach@users.noreply.github.com>2019-07-07 03:25:27 +0200
committerGitHub <noreply@github.com>2019-07-07 03:25:27 +0200
commitfb9124b6cdc7366c1dc8c37523e7ff6aad783a23 (patch)
tree8263269934f2393f66725263b7f3a38c53955ae5 /src/core/hle/kernel/vm_manager.h
parentMerge pull request #2684 from SciresM/suspend_tick (diff)
parentmemory: Remove unused includes (diff)
downloadyuzu-fb9124b6cdc7366c1dc8c37523e7ff6aad783a23.tar
yuzu-fb9124b6cdc7366c1dc8c37523e7ff6aad783a23.tar.gz
yuzu-fb9124b6cdc7366c1dc8c37523e7ff6aad783a23.tar.bz2
yuzu-fb9124b6cdc7366c1dc8c37523e7ff6aad783a23.tar.lz
yuzu-fb9124b6cdc7366c1dc8c37523e7ff6aad783a23.tar.xz
yuzu-fb9124b6cdc7366c1dc8c37523e7ff6aad783a23.tar.zst
yuzu-fb9124b6cdc7366c1dc8c37523e7ff6aad783a23.zip
Diffstat (limited to 'src/core/hle/kernel/vm_manager.h')
-rw-r--r--src/core/hle/kernel/vm_manager.h20
1 files changed, 10 insertions, 10 deletions
diff --git a/src/core/hle/kernel/vm_manager.h b/src/core/hle/kernel/vm_manager.h
index 752ae62f9..9fe6ac3f4 100644
--- a/src/core/hle/kernel/vm_manager.h
+++ b/src/core/hle/kernel/vm_manager.h
@@ -596,17 +596,17 @@ public:
/// Determines whether or not the specified range is within the map region.
bool IsWithinMapRegion(VAddr address, u64 size) const;
- /// Gets the base address of the new map region.
- VAddr GetNewMapRegionBaseAddress() const;
+ /// Gets the base address of the stack region.
+ VAddr GetStackRegionBaseAddress() const;
- /// Gets the end address of the new map region.
- VAddr GetNewMapRegionEndAddress() const;
+ /// Gets the end address of the stack region.
+ VAddr GetStackRegionEndAddress() const;
- /// Gets the total size of the new map region in bytes.
- u64 GetNewMapRegionSize() const;
+ /// Gets the total size of the stack region in bytes.
+ u64 GetStackRegionSize() const;
- /// Determines whether or not the given address range is within the new map region
- bool IsWithinNewMapRegion(VAddr address, u64 size) const;
+ /// Determines whether or not the given address range is within the stack region
+ bool IsWithinStackRegion(VAddr address, u64 size) const;
/// Gets the base address of the TLS IO region.
VAddr GetTLSIORegionBaseAddress() const;
@@ -726,8 +726,8 @@ private:
VAddr map_region_base = 0;
VAddr map_region_end = 0;
- VAddr new_map_region_base = 0;
- VAddr new_map_region_end = 0;
+ VAddr stack_region_base = 0;
+ VAddr stack_region_end = 0;
VAddr tls_io_region_base = 0;
VAddr tls_io_region_end = 0;